New PCI ne200 card

Steve McIntyre (stevem@chiark.greenend.org.uk)
Thu, 7 Aug 1997 22:04:15 +0100 (BST)


Patch against 2.0.30 for Netvin card; I've also sent details of the new
card to the PCI maintainer...

--- linux/drivers/net/ne.c Sat Aug 2 10:24:46 1997
+++ linux-2.0.30/drivers/net/ne.c Sat Aug 2 02:43:16 1997
@@ -162,9 +162,14 @@
unsigned char pci_bus, pci_device_fn;
unsigned int pci_ioaddr;

- /* Currently only Realtek are making PCI ne2k clones. */
+ /* Currently only Realtek and NetVin are making PCI
+ ne2k clones. */
if (pcibios_find_device (PCI_VENDOR_ID_REALTEK,
PCI_DEVICE_ID_REALTEK_8029, pci_index,
+ &pci_bus, &pci_device_fn) != 0)
+ break;
+ if (pcibios_find_device (PCI_VENDOR_ID_NETVIN,
+ PCI_DEVICE_ID_NETVIN_NV5000SC, pci_index,
&pci_bus, &pci_device_fn) != 0)
break; /* OK, now try to probe for std. ISA card
*/
pcibios_read_config_byte(pci_bus, pci_device_fn,

-- 
Steve McIntyre, CURS CCE, Cambridge, UK.         stevem@chiark.greenend.org.uk
Use Debian GNU/Linux - upgrade your Windoze box today!  http://www.debian.org/
"Can't keep my eyes from the circling sky,                 +------------------
"Tongue-tied & twisted, Just an earth-bound misfit, I..."  |Finger for PGP key

Mail for me sent to cam.ac.uk addresses will start bouncing soon. Please use stevem@chiark.greenend.org.uk or steve_mcintyre@geocities.com instead. Thanks.